aiodagpi
========

.. image:: https://img.shields.io/pypi/v/aiodagpi.svg
    :target: https://pypi.python.org/pypi/aiodagpi
    :alt: Latest PyPI version

An asynchronous python API wrapper for Dagpi : https://dagpi.tk

Usage
-----

CURRENTLY IN PLANNING, PAGE USED FOR RESERVATION.

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`aiodagpi` was written by `Raj Sharma <yrsharma@icloud.com>`_.
